@@ -1,6 +1,9 @@
 package EWS::Client;
 BEGIN {
-  $EWS::Client::VERSION = '1.130540_002';
+  $EWS::Client::VERSION = '1.131710_001';
+}
+BEGIN {
+  $EWS::Client::VERSION = '1.130570';
 }
 use Moose;
 
@@ -8,10 +11,14 @@ with qw/
     EWS::Client::Role::SOAP
     EWS::Client::Role::GetItem
     EWS::Client::Role::FindItem
+    EWS::Client::Role::FindFolder
+    EWS::Client::Role::GetFolder
 /;
 use EWS::Client::Contacts;
 use EWS::Client::Calendar;
+use EWS::Client::Folder;
 use URI::Escape ();
+use Log::Report;
 
 has username => (
     is => 'rw',
@@ -53,6 +60,18 @@ sub _build_calendar {
     return EWS::Client::Calendar->new({ client => $self });
 }
 
+has folders => (
+    is => 'ro',
+    isa => 'EWS::Client::Folder',
+    lazy_build => 1,
+);
+
+sub _build_folders {
+    my $self = shift;
+    return EWS::Client::Folder->new({ client => $self });
+}
+
+
 sub BUILDARGS {
     my ($class, @rest) = @_;
     my $params = (scalar @rest == 1 ? $rest[0] : {@rest});
@@ -100,7 +119,7 @@ EWS::Client - Microsoft Exchange Web Services Client
 
 =head1 VERSION
 
-version 1.130540_002
+version 1.131710_001
 
 =head1 SYNOPSIS
 
@@ -207,6 +226,12 @@ Retrieves the L<EWS::Client::Contacts> object which allows retrieval of
 contact entries and their telephone numbers. See that linked manual page for
 more details.
 
+=head2 $ews->folders()
+
+Retrieves the L<EWS::Client::Folder> object which allows retrieval of
+mailbox folder entries and their sizes. See that linked manual page for
+more details.
+
 =head1 KNOWN ISSUES
 
 =over 4
